@@ -205,6 +205,8 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 	 * the ::started signal is emitted in the miner
 	 * right after it has been started through
 	 * tracker_miner_start().
+	 *
+	 * Since: 0.8
 	 **/
 	signals[STARTED] =
 		g_signal_new ("started",
@@ -221,6 +223,8 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 	 * the ::stopped signal is emitted in the miner
 	 * right after it has been stopped through
 	 * tracker_miner_stop().
+	 *
+	 * Since: 0.8
 	 **/
 	signals[STOPPED] =
 		g_signal_new ("stopped",
@@ -238,6 +242,8 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 	 * there is any reason to pause, either
 	 * internal (through tracker_miner_pause()) or
 	 * external (through DBus, see #TrackerMinerManager).
+	 *
+	 * Since: 0.8
 	 **/
 	signals[PAUSED] =
 		g_signal_new ("paused",
@@ -254,6 +260,8 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 	 * the ::resumed signal is emitted whenever
 	 * all reasons to pause have disappeared, see
 	 * tracker_miner_resume() and #TrackerMinerManager.
+	 *
+	 * Since: 0.8
 	 **/
 	signals[RESUMED] =
 		g_signal_new ("resumed",
@@ -273,6 +281,8 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 	 * to indicate progress about the data mining process. @status will
 	 * contain a translated string with the current miner status and @progress
 	 * will indicate how much has been processed so far.
+	 *
+	 * Since: 0.8
 	 **/
 	signals[PROGRESS] =
 		g_signal_new ("progress",
@@ -293,6 +303,8 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 	 * the ::ignore-next-update signal is emitted in the miner
 	 * right after it has been asked to mark @urls as to ignore on next update
 	 * through tracker_miner_ignore_next_update().
+	 *
+	 * Since: 0.8
 	 **/
 	signals[IGNORE_NEXT_UPDATE] =
 		g_signal_new ("ignore-next-update",
@@ -355,24 +367,28 @@ miner_initable_init (GInitable     *initable,
 	};
 
 	/* Try to get SPARQL connection... */
-	miner->private->connection = tracker_sparql_connection_get (NULL, &inner_error);
-	if (!miner->private->connection) {
+	miner->priv->connection = tracker_sparql_connection_get (NULL, &inner_error);
+	if (!miner->priv->connection) {
 		g_propagate_error (error, inner_error);
 		return FALSE;
 	}
 
 	/* Try to get DBus connection... */
-	miner->private->d_connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &inner_error);
-	if (!miner->private->d_connection) {
+	miner->priv->d_connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &inner_error);
+	if (!miner->priv->d_connection) {
 		g_propagate_error (error, inner_error);
 		return FALSE;
 	}
 
 	/* Setup introspection data */
-	miner->private->introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
+	miner->priv->introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, &inner_error);
+	if (!miner->priv->introspection_data) {
+		g_propagate_error (error, inner_error);
+		return FALSE;
+	}
 
 	/* Check miner has a proper name */
-	if (!miner->private->name) {
+	if (!miner->priv->name) {
 		g_set_error (error,
 		             TRACKER_MINER_ERROR,
 		             0,
@@ -382,23 +398,23 @@ miner_initable_init (GInitable     *initable,
 	}
 
 	/* Setup full name */
-	miner->private->full_name = g_strconcat (TRACKER_MINER_DBUS_NAME_PREFIX,
-	                                         miner->private->name,
+	miner->priv->full_name = g_strconcat (TRACKER_MINER_DBUS_NAME_PREFIX,
+	                                         miner->priv->name,
 	                                         NULL);
 
 	/* Register the D-Bus object */
-	miner->private->full_path = g_strconcat (TRACKER_MINER_DBUS_PATH_PREFIX,
-	                                         miner->private->name,
+	miner->priv->full_path = g_strconcat (TRACKER_MINER_DBUS_PATH_PREFIX,
+	                                         miner->priv->name,
 	                                         NULL);
 
 	g_message ("Registering D-Bus object...");
-	g_message ("  Path:'%s'", miner->private->full_path);
+	g_message ("  Path:'%s'", miner->priv->full_path);
 	g_message ("  Object Type:'%s'", G_OBJECT_TYPE_NAME (miner));
 
-	miner->private->registration_id =
-		g_dbus_connection_register_object (miner->private->d_connection,
-		                                   miner->private->full_path,
-	                                       miner->private->introspection_data->interfaces[0],
+	miner->priv->registration_id =
+		g_dbus_connection_register_object (miner->priv->d_connection,
+		                                   miner->priv->full_path,
+	                                       miner->priv->introspection_data->interfaces[0],
 	                                       &interface_vtable,
 	                                       miner,
 	                                       NULL,
@@ -407,18 +423,18 @@ miner_initable_init (GInitable     *initable,
 		g_propagate_error (error, inner_error);
 		g_prefix_error (error,
 		                "Could not register the D-Bus object '%s'. ",
-		                miner->private->full_path);
+		                miner->priv->full_path);
 		return FALSE;
 	}
 
 	/* Request the D-Bus name */
-	reply = g_dbus_connection_call_sync (miner->private->d_connection,
+	reply = g_dbus_connection_call_sync (miner->priv->d_connection,
 	                                     "org.freedesktop.DBus",
 	                                     "/org/freedesktop/DBus",
 	                                     "org.freedesktop.DBus",
 	                                     "RequestName",
 	                                     g_variant_new ("(su)",
-	                                                    miner->private->full_name,
+	                                                    miner->priv->full_name,
 	                                                    0x4 /* DBUS_NAME_FLAG_DO_NOT_QUEUE */),
 	                                     G_VARIANT_TYPE ("(u)"),
 	                                     0, -1, NULL, &inner_error);
@@ -426,7 +442,7 @@ miner_initable_init (GInitable     *initable,
 		g_propagate_error (error, inner_error);
 		g_prefix_error (error,
 		                "Could not acquire name:'%s'. ",
-		                miner->private->full_name);
+		                miner->priv->full_name);
 		return FALSE;
 	}
 
@@ -439,11 +455,11 @@ miner_initable_init (GInitable     *initable,
 		             0,
 		             "D-Bus service name:'%s' is already taken, "
 		             "perhaps the application is already running?",
-		             miner->private->full_name);
+		             miner->priv->full_name);
 		return FALSE;
 	}
 
-	miner->private->watch_name_id = g_bus_watch_name (G_BUS_TYPE_SESSION,
+	miner->priv->watch_name_id = g_bus_watch_name (G_BUS_TYPE_SESSION,
 	                                                  TRACKER_SERVICE,
 	                                                  G_BUS_NAME_WATCHER_FLAGS_NONE,
 	                                                  on_tracker_store_appeared,
@@ -458,7 +474,7 @@ static void
 tracker_miner_init (TrackerMiner *miner)
 {
 	TrackerMinerPrivate *priv;
-	miner->private = priv = TRACKER_MINER_GET_PRIVATE (miner);
+	miner->priv = priv = TRACKER_MINER_GET_PRIVATE (miner);
 
 	priv->pauses = g_hash_table_new_full (g_direct_hash,
 	                                      g_direct_equal,
@@ -470,18 +486,18 @@ static void
 miner_update_progress (TrackerMiner *miner)
 {
 	g_signal_emit (miner, signals[PROGRESS], 0,
-	               miner->private->status,
-	               miner->private->progress);
+	               miner->priv->status,
+	               miner->priv->progress);
 
-	if (miner->private->d_connection) {
-		g_dbus_connection_emit_signal (miner->private->d_connection,
+	if (miner->priv->d_connection) {
+		g_dbus_connection_emit_signal (miner->priv->d_connection,
 		                               NULL,
-		                               miner->private->full_path,
+		                               miner->priv->full_path,
 		                               TRACKER_MINER_DBUS_INTERFACE,
 		                               "Progress",
 		                               g_variant_new ("(sd)",
-		                                              miner->private->status,
-		                                              miner->private->progress),
+		                                              miner->priv->status,
+		                                              miner->priv->progress),
 		                               NULL);
 	}
 }
@@ -496,21 +512,21 @@ miner_set_property (GObject      *object,
 
 	switch (prop_id) {
 	case PROP_NAME:
-		g_free (miner->private->name);
-		miner->private->name = g_value_dup_string (value);
+		g_free (miner->priv->name);
+		miner->priv->name = g_value_dup_string (value);
 		break;
 	case PROP_STATUS: {
 		const gchar *new_status;
 
 		new_status = g_value_get_string (value);
-		if (miner->private->status && new_status &&
-		    strcmp (miner->private->status, new_status) == 0) {
+		if (miner->priv->status && new_status &&
+		    strcmp (miner->priv->status, new_status) == 0) {
 			/* Same, do nothing */
 			break;
 		}
 
-		g_free (miner->private->status);
-		miner->private->status = g_strdup (new_status);
+		g_free (miner->priv->status);
+		miner->priv->status = g_strdup (new_status);
 		miner_update_progress (miner);
 		break;
 	}
@@ -525,12 +541,12 @@ miner_set_property (GObject      *object,
 		 *
 		 * Only notify 1% changes
 		 */
-		if (new_progress == miner->private->progress) {
+		if (new_progress == miner->priv->progress) {
 			/* Same, do nothing */
 			break;
 		}
 
-		miner->private->progress = new_progress;
+		miner->priv->progress = new_progress;
 		miner_update_progress (miner);
 		break;
 	}
@@ -550,13 +566,13 @@ miner_get_property (GObject    *object,
 
 	switch (prop_id) {
 	case PROP_NAME:
-		g_value_set_string (value, miner->private->name);
+		g_value_set_string (value, miner->priv->name);
 		break;
 	case PROP_STATUS:
-		g_value_set_string (value, miner->private->status);
+		g_value_set_string (value, miner->priv->status);
 		break;
 	case PROP_PROGRESS:
-		g_value_set_double (value, miner->private->progress);
+		g_value_set_double (value, miner->priv->progress);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -599,6 +615,8 @@ pause_data_destroy (gpointer data)
  * Returns the #GQuark used to identify miner errors in GError structures.
  *
  * Returns: the error #GQuark
+ *
+ * Since: 0.8
  **/
 GQuark
 tracker_miner_error_quark (void)
@@ -611,21 +629,23 @@ tracker_miner_error_quark (void)
  * @miner: a #TrackerMiner
  *
  * Tells the miner to start processing data.
+ *
+ * Since: 0.8
  **/
 void
 tracker_miner_start (TrackerMiner *miner)
 {
 	g_return_if_fail (TRACKER_IS_MINER (miner));
-	g_return_if_fail (miner->private->started == FALSE);
+	g_return_if_fail (miner->priv->started == FALSE);
 
-	miner->private->started = TRUE;
+	miner->priv->started = TRUE;
 
 	g_signal_emit (miner, signals[STARTED], 0);
 
-	if (miner->private->d_connection) {
-		g_dbus_connection_emit_signal (miner->private->d_connection,
+	if (miner->priv->d_connection) {
+		g_dbus_connection_emit_signal (miner->priv->d_connection,
 		                               NULL,
-		                               miner->private->full_path,
+		                               miner->priv->full_path,
 		                               TRACKER_MINER_DBUS_INTERFACE,
 		                               "Started",
 		                               NULL,
@@ -638,21 +658,23 @@ tracker_miner_start (TrackerMiner *miner)
  * @miner: a #TrackerMiner
  *
  * Tells the miner to stop processing data.
+ *
+ * Since: 0.8
  **/
 void
 tracker_miner_stop (TrackerMiner *miner)
 {
 	g_return_if_fail (TRACKER_IS_MINER (miner));
-	g_return_if_fail (miner->private->started == TRUE);
+	g_return_if_fail (miner->priv->started == TRUE);
 
-	miner->private->started = FALSE;
+	miner->priv->started = FALSE;
 
 	g_signal_emit (miner, signals[STOPPED], 0);
 
-	if (miner->private->d_connection) {
-		g_dbus_connection_emit_signal (miner->private->d_connection,
+	if (miner->priv->d_connection) {
+		g_dbus_connection_emit_signal (miner->priv->d_connection,
 		                               NULL,
-		                               miner->private->full_path,
+		                               miner->priv->full_path,
 		                               TRACKER_MINER_DBUS_INTERFACE,
 		                               "Stopped",
 		                               NULL,
@@ -663,9 +685,11 @@ tracker_miner_stop (TrackerMiner *miner)
 /**
  * tracker_miner_ignore_next_update:
  * @miner: a #TrackerMiner
- * @urls: the urls to mark as to ignore on next update
+ * @urls: (in): the urls to mark as to ignore on next update
  *
  * Tells the miner to mark @urls are to ignore on next update.
+ *
+ * Since: 0.8
  **/
 void
 tracker_miner_ignore_next_update (TrackerMiner *miner,
@@ -683,13 +707,15 @@ tracker_miner_ignore_next_update (TrackerMiner *miner,
  * Returns #TRUE if the miner has been started.
  *
  * Returns: #TRUE if the miner is already started.
+ *
+ * Since: 0.8
  **/
 gboolean
 tracker_miner_is_started (TrackerMiner *miner)
 {
 	g_return_val_if_fail (TRACKER_IS_MINER (miner), TRUE);
 
-	return miner->private->started;
+	return miner->priv->started;
 }
 
 /**
@@ -699,13 +725,34 @@ tracker_miner_is_started (TrackerMiner *miner)
  * Returns #TRUE if the miner is paused.
  *
  * Returns: #TRUE if the miner is paused.
+ *
+ * Since: 0.10
  **/
 gboolean
 tracker_miner_is_paused (TrackerMiner *miner)
 {
 	g_return_val_if_fail (TRACKER_IS_MINER (miner), TRUE);
 
-	return g_hash_table_size (miner->private->pauses) > 0 ? TRUE : FALSE;
+	return g_hash_table_size (miner->priv->pauses) > 0 ? TRUE : FALSE;
+}
+
+/**
+ * tracker_miner_get_n_pause_reasons:
+ * @miner: a #TrackerMiner
+ *
+ * Returns the number of pause reasons holding @miner from
+ * indexing contents.
+ *
+ * Returns: The number of current pause reasons
+ *
+ * Since: 0.10.5
+ **/
+guint
+tracker_miner_get_n_pause_reasons (TrackerMiner *miner)
+{
+	g_return_val_if_fail (TRACKER_IS_MINER (miner), 0);
+
+	return g_hash_table_size (miner->priv->pauses);
 }
 
 static gint
@@ -719,7 +766,7 @@ tracker_miner_pause_internal (TrackerMiner  *miner,
 	gpointer key, value;
 
 	/* Check this is not a duplicate pause */
-	g_hash_table_iter_init (&iter, miner->private->pauses);
+	g_hash_table_iter_init (&iter, miner->priv->pauses);
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
 		PauseData *pd = value;
 
@@ -734,19 +781,19 @@ tracker_miner_pause_internal (TrackerMiner  *miner,
 
 	pd = pause_data_new (application, reason);
 
-	g_hash_table_insert (miner->private->pauses,
+	g_hash_table_insert (miner->priv->pauses,
 	                     GINT_TO_POINTER (pd->cookie),
 	                     pd);
 
-	if (g_hash_table_size (miner->private->pauses) == 1) {
+	if (g_hash_table_size (miner->priv->pauses) == 1) {
 		/* Pause */
-		g_message ("Miner:'%s' is pausing", miner->private->name);
+		g_message ("Miner:'%s' is pausing", miner->priv->name);
 		g_signal_emit (miner, signals[PAUSED], 0);
 
-		if (miner->private->d_connection) {
-			g_dbus_connection_emit_signal (miner->private->d_connection,
+		if (miner->priv->d_connection) {
+			g_dbus_connection_emit_signal (miner->priv->d_connection,
 			                               NULL,
-			                               miner->private->full_path,
+			                               miner->priv->full_path,
 			                               TRACKER_MINER_DBUS_INTERFACE,
 			                               "Paused",
 			                               NULL,
@@ -761,13 +808,15 @@ tracker_miner_pause_internal (TrackerMiner  *miner,
  * tracker_miner_pause:
  * @miner: a #TrackerMiner
  * @reason: reason to pause
- * @error: return location for errors
+ * @error: (out callee-allocates) (transfer full) (allow-none): return location for errors
  *
  * Asks @miner to pause. On success the cookie ID is returned,
  * this is what must be used in tracker_miner_resume() to resume
  * operations. On failure @error will be set and -1 will be returned.
  *
  * Returns: The pause cookie ID.
+ *
+ * Since: 0.8
  **/
 gint
 tracker_miner_pause (TrackerMiner  *miner,
@@ -782,7 +831,7 @@ tracker_miner_pause (TrackerMiner  *miner,
 	application = g_get_application_name ();
 
 	if (!application) {
-		application = miner->private->name;
+		application = miner->priv->name;
 	}
 
 	return tracker_miner_pause_internal (miner, application, reason, error);
@@ -792,13 +841,15 @@ tracker_miner_pause (TrackerMiner  *miner,
  * tracker_miner_resume:
  * @miner: a #TrackerMiner
  * @cookie: pause cookie
- * @error: return location for errors
+ * @error: (out) (transfer full) (allow-none): return location for errors
  *
  * Asks the miner to resume processing. The cookie must be something
  * returned by tracker_miner_pause(). The miner won't actually resume
  * operations until all pause requests have been resumed.
  *
  * Returns: #TRUE if the cookie was valid.
+ *
+ * Since: 0.8
  **/
 gboolean
 tracker_miner_resume (TrackerMiner  *miner,
@@ -807,21 +858,21 @@ tracker_miner_resume (TrackerMiner  *miner,
 {
 	g_return_val_if_fail (TRACKER_IS_MINER (miner), FALSE);
 
-	if (!g_hash_table_remove (miner->private->pauses, GINT_TO_POINTER (cookie))) {
+	if (!g_hash_table_remove (miner->priv->pauses, GINT_TO_POINTER (cookie))) {
 		g_set_error_literal (error, TRACKER_MINER_ERROR, 0,
 		                     _("Cookie not recognized to resume paused miner"));
 		return FALSE;
 	}
 
-	if (g_hash_table_size (miner->private->pauses) == 0) {
+	if (g_hash_table_size (miner->priv->pauses) == 0) {
 		/* Resume */
-		g_message ("Miner:'%s' is resuming", miner->private->name);
+		g_message ("Miner:'%s' is resuming", miner->priv->name);
 		g_signal_emit (miner, signals[RESUMED], 0);
 
-		if (miner->private->d_connection) {
-			g_dbus_connection_emit_signal (miner->private->d_connection,
+		if (miner->priv->d_connection) {
+			g_dbus_connection_emit_signal (miner->priv->d_connection,
 			                               NULL,
-			                               miner->private->full_path,
+			                               miner->priv->full_path,
 			                               TRACKER_MINER_DBUS_INTERFACE,
 			                               "Resumed",
 			                               NULL,
@@ -838,12 +889,14 @@ tracker_miner_resume (TrackerMiner  *miner,
  *
  * Gets the #TrackerSparqlConnection initialized by @miner
  *
- * Returns: a #TrackerSparqlConnection.
+ * Returns: (transfer none): a #TrackerSparqlConnection.
+ *
+ * Since: 0.10
  **/
 TrackerSparqlConnection *
 tracker_miner_get_connection (TrackerMiner *miner)
 {
-	return miner->private->connection;
+	return miner->priv->connection;
 }
 
 /**
@@ -852,12 +905,14 @@ tracker_miner_get_connection (TrackerMiner *miner)
  *
  * Gets the #GDBusConnection initialized by @miner
  *
- * Returns: a #GDBusConnection.
+ * Returns: (transfer none): a #GDBusConnection.
+ *
+ * Since: 0.10
  **/
 GDBusConnection *
 tracker_miner_get_dbus_connection (TrackerMiner *miner)
 {
-	return miner->private->d_connection;
+	return miner->priv->d_connection;
 }
 
 /**
@@ -867,11 +922,13 @@ tracker_miner_get_dbus_connection (TrackerMiner *miner)
  * Gets the DBus name registered by @miner
  *
  * Returns: a constant string which should not be modified by the caller.
+ *
+ * Since: 0.10
  **/
 G_CONST_RETURN gchar *
 tracker_miner_get_dbus_full_name (TrackerMiner *miner)
 {
-	return miner->private->full_name;
+	return miner->priv->full_name;
 }
 
 /**
@@ -881,11 +938,13 @@ tracker_miner_get_dbus_full_name (TrackerMiner *miner)
  * Gets the DBus path registered by @miner
  *
  * Returns: a constant string which should not be modified by the caller.
+ *
+ * Since: 0.10
  **/
 G_CONST_RETURN gchar *
 tracker_miner_get_dbus_full_path (TrackerMiner *miner)
 {
-	return miner->private->full_path;
+	return miner->priv->full_path;
 }
 
 static void
@@ -893,34 +952,34 @@ miner_finalize (GObject *object)
 {
 	TrackerMiner *miner = TRACKER_MINER (object);
 
-	if (miner->private->watch_name_id != 0) {
-		g_bus_unwatch_name (miner->private->watch_name_id);
+	if (miner->priv->watch_name_id != 0) {
+		g_bus_unwatch_name (miner->priv->watch_name_id);
 	}
 
-	if (miner->private->registration_id != 0) {
-		g_dbus_connection_unregister_object (miner->private->d_connection,
-		                                     miner->private->registration_id);
+	if (miner->priv->registration_id != 0) {
+		g_dbus_connection_unregister_object (miner->priv->d_connection,
+		                                     miner->priv->registration_id);
 	}
 
-	if (miner->private->introspection_data) {
-		g_dbus_node_info_unref (miner->private->introspection_data);
+	if (miner->priv->introspection_data) {
+		g_dbus_node_info_unref (miner->priv->introspection_data);
 	}
 
-	if (miner->private->d_connection) {
-		g_object_unref (miner->private->d_connection);
+	if (miner->priv->d_connection) {
+		g_object_unref (miner->priv->d_connection);
 	}
 
-	g_free (miner->private->status);
-	g_free (miner->private->name);
-	g_free (miner->private->full_name);
-	g_free (miner->private->full_path);
+	g_free (miner->priv->status);
+	g_free (miner->priv->name);
+	g_free (miner->priv->full_name);
+	g_free (miner->priv->full_path);
 
-	if (miner->private->connection) {
-		g_object_unref (miner->private->connection);
+	if (miner->priv->connection) {
+		g_object_unref (miner->priv->connection);
 	}
 
-	if (miner->private->pauses) {
-		g_hash_table_unref (miner->private->pauses);
+	if (miner->priv->pauses) {
+		g_hash_table_unref (miner->priv->pauses);
 	}
 
 	G_OBJECT_CLASS (tracker_miner_parent_class)->finalize (object);
@@ -1027,7 +1086,7 @@ handle_method_call_get_pause_details (TrackerMiner          *miner,
 
 	applications = NULL;
 	reasons = NULL;
-	g_hash_table_iter_init (&iter, miner->private->pauses);
+	g_hash_table_iter_init (&iter, miner->priv->pauses);
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
 		PauseData *pd = value;
 
@@ -1062,7 +1121,8 @@ handle_method_call_get_progress (TrackerMiner          *miner,
 
 	tracker_dbus_request_end (request, NULL);
 	g_dbus_method_invocation_return_value (invocation,
-	                                       g_variant_new ("(d)", miner->private->progress));
+	                                       g_variant_new ("(d)",
+	                                                      miner->priv->progress));
 }
 
 static void
@@ -1076,7 +1136,8 @@ handle_method_call_get_status (TrackerMiner          *miner,
 
 	tracker_dbus_request_end (request, NULL);
 	g_dbus_method_invocation_return_value (invocation,
-	                                       g_variant_new ("(s)", miner->private->status ? miner->private->status : ""));
+	                                       g_variant_new ("(s)",
+	                                                      miner->priv->status ? miner->priv->status : ""));
 
 }
 
@@ -1153,13 +1214,13 @@ on_tracker_store_appeared (GDBusConnection *connection,
 	TrackerMiner *miner = user_data;
 
 	g_debug ("Miner:'%s' noticed store availability has changed to AVAILABLE",
-	         miner->private->name);
+	         miner->priv->name);
 
-	if (miner->private->availability_cookie != 0) {
+	if (miner->priv->availability_cookie != 0) {
 		GError *error = NULL;
 
 		tracker_miner_resume (miner,
-		                      miner->private->availability_cookie,
+		                      miner->priv->availability_cookie,
 		                      &error);
 
 		if (error) {
@@ -1167,7 +1228,7 @@ on_tracker_store_appeared (GDBusConnection *connection,
 			g_error_free (error);
 		}
 
-		miner->private->availability_cookie = 0;
+		miner->priv->availability_cookie = 0;
 	}
 }
 
@@ -1179,9 +1240,9 @@ on_tracker_store_disappeared (GDBusConnection *connection,
 	TrackerMiner *miner = user_data;
 
 	g_debug ("Miner:'%s' noticed store availability has changed to UNAVAILABLE",
-	         miner->private->name);
+	         miner->priv->name);
 
-	if (miner->private->availability_cookie == 0) {
+	if (miner->priv->availability_cookie == 0) {
 		GError *error = NULL;
 		gint cookie_id;
 
@@ -1193,7 +1254,7 @@ on_tracker_store_disappeared (GDBusConnection *connection,
 			g_warning ("Could not pause, %s", error->message);
 			g_error_free (error);
 		} else {
-			miner->private->availability_cookie = cookie_id;
+			miner->priv->availability_cookie = cookie_id;
 		}
 	}
 }
